@@ -1,3 +1,4 @@
+import time
 from wencaipy.stock import stock_prs
 
 from wencaipy.common.dataToExcel import read_data_from_excel
@@ -11,4 +12,8 @@ def save_stock_prs_to_excel():
     
     
 if __name__ == "__main__":
-    save_stock_prs_to_excel()
\ No newline at end of file
+    start_time = time.perf_counter()
+    save_stock_prs_to_excel()
+    end_time = time.perf_counter()
+    times = end_time - start_time
+    print(f"Tasted times: {times}s")
\ No newline at end of file
